@@ -293,6 +293,8 @@ class ArgumentParser(argparse.ArgumentParser):
                 configargparse args will be ignored. If false, they will be
                 processed and appended to the commandline like other args, and
                 can be retrieved using parse_known_args() instead of parse_args()
+            config_file_open_func: function used to open a config file for reading 
+                or writing. Needs to return a file-like object.
             config_file_parser_class: configargparse.ConfigFileParser subclass
                 which determines the config file format. configargparse comes
                 with DefaultConfigFileParser and YAMLConfigFileParser.
@@ -335,6 +337,8 @@ class ArgumentParser(argparse.ArgumentParser):
             "command line args and writes them out to a config file at the "
             "given path, then exits")
 
+        self._config_file_open_func = kwargs.pop('config_file_open_func', open)
+
         self._add_config_file_help = add_config_file_help
         self._add_env_var_help = add_env_var_help
         self._auto_env_var_prefix = auto_env_var_prefix
@@ -554,7 +558,7 @@ class ArgumentParser(argparse.ArgumentParser):
         for output_file_path in output_file_paths:
             # validate the output file path
             try:
-                with open(output_file_path, "w") as output_file:
+                with self._config_file_open_func(output_file_path, "w") as output_file:
                     pass
             except IOError as e:
                 raise ValueError("Couldn't open {} for writing: {}".format(
@@ -565,7 +569,7 @@ class ArgumentParser(argparse.ArgumentParser):
                 self._source_to_settings, parsed_namespace)
             file_contents = self._config_file_parser.serialize(config_items)
             for output_file_path in output_file_paths:
-                with open(output_file_path, "w") as output_file:
+                with self._config_file_open_func(output_file_path, "w") as output_file:
                     output_file.write(file_contents)
             message = "Wrote config file to " + ", ".join(output_file_paths)
             if exit_after:
@@ -711,8 +715,10 @@ class ArgumentParser(argparse.ArgumentParser):
             command_line_args: List of all args
         """
         # open any default config files
-        config_files = [open(f) for files in map(glob.glob, map(os.path.expanduser, self._default_config_files))
-                        for f in files]
+        config_files = []
+        for files in map(glob.glob, map(os.path.expanduser, self._default_config_files)):
+            for f in files:
+                config_files.append(self._config_file_open_func(f))
 
         # list actions with is_config_file_arg=True. Its possible there is more
         # than one such arg.
@@ -752,7 +758,7 @@ class ArgumentParser(argparse.ArgumentParser):
             if not os.path.isfile(user_config_file):
                 self.error('File not found: %s' % user_config_file)
 
-            config_files += [open(user_config_file)]
+            config_files += [self._config_file_open_func(user_config_file)]
 
         return config_files
 
